Crate freedesktop_icon_lookup

Crate freedesktop_icon_lookup 

freedesktop-icon-lookup

A library for searching a path with given app name based on Freedesktop icon lookup spec. The implementation eagarly scans all directories in advance so multiple lookups are executed way faster and without real filesystem scan.

Feature list

  • Multiple themes support, including inherited;
  • Advanced lookup among all found

Example

use freedesktop_icon_lookup::{Cache, LookupParam};

let theme = "Adwaita";
let mut cache = Cache::new()?;
cache.load(theme)?;
let _: Option<PathBuf> = cache.lookup("firefox", theme);

Alternatives

freedesktop-icons might be a better option if you only need a few icons to search.

Structs

Cache
Icon cache, before lookups one may need to load required theme(s) explicitly either with Cache::load or Cache::load_default.
IconInfo
Information about found icon
LookupParam
Search parameters for Cache::lookup_param search.

Enums

Error

Type Aliases

Result