Cache

Struct Cache 

pub struct Cache { /* private fields */ }
Icon cache, before lookups one may need to load required theme(s) explicitly either with Cache::load or Cache::load_default.

Implementations

Source

impl Cache

pub fn new() -> Result<Self>

Creates new cache. Most of the lookups are to be failed at this point. Consider loading icons afterwards.

pub fn themes(&self) -> impl Iterator<Item = &str> + '_

Returns iterator with a loaded themes.

pub fn load_default(&mut self) -> Result<()>

Load icons for default (HiColor) icon theme.

pub fn load(&mut self, theme: impl Into<String>) -> Result<()>

Load icons for specified icon theme.

pub fn lookup_advanced<'a, F>( &'a self, name: &str, theme: impl Into<Option<&'a str>>, f: F, ) -> Option<PathBuf>
where F: FnMut(&[IconInfo]) -> Option<usize> + Copy,

Advanced icon lookup provides general solution over Cache::lookup. Similarly it requires an icon name and optional theme to look for. Also a provided closure is called for a list of discovered IconInfo’s. Notice that icons list might be incomplete (e.g doesn’t include inherited themes).

pub fn lookup<'a>( &'a self, name: &str, theme: impl Into<Option<&'a str>>, ) -> Option<PathBuf>

Icon lookup for a specified name and optional theme to look for. If theme is unspecified the default one is used.

pub fn lookup_param<'a>(&'a self, param: LookupParam<'a>) -> Option<PathBuf>

Icon lookup with a provided LookupParam. It works as described in Freedesktop icon lookup spec.